==> cdktf-cdktf-provider-gitlab-6.0.1.tar.gz: package/docs/API.typescript.md <==
# Submodules <a name="Submodules" id="submodules"></a>

The following submodules are available:
- [applicationSettings](./applicationSettings.typescript.md)
- [branch](./branch.typescript.md)
- [branchProtection](./branchProtection.typescript.md)
- [clusterAgent](./clusterAgent.typescript.md)
- [clusterAgentToken](./clusterAgentToken.typescript.md)
- [dataGitlabBranch](./dataGitlabBranch.typescript.md)
- [dataGitlabClusterAgent](./dataGitlabClusterAgent.typescript.md)
- [dataGitlabClusterAgents](./dataGitlabClusterAgents.typescript.md)
- [dataGitlabCurrentUser](./dataGitlabCurrentUser.typescript.md)
- [dataGitlabGroup](./dataGitlabGroup.typescript.md)
- [dataGitlabGroupHook](./dataGitlabGroupHook.typescript.md)
- [dataGitlabGroupHooks](./dataGitlabGroupHooks.typescript.md)
- [dataGitlabGroupMembership](./dataGitlabGroupMembership.typescript.md)
- [dataGitlabGroupSubgroups](./dataGitlabGroupSubgroups.typescript.md)
- [dataGitlabGroupVariable](./dataGitlabGroupVariable.typescript.md)
- [dataGitlabGroupVariables](./dataGitlabGroupVariables.typescript.md)
- [dataGitlabGroups](./dataGitlabGroups.typescript.md)
- [dataGitlabInstanceDeployKeys](./dataGitlabInstanceDeployKeys.typescript.md)
- [dataGitlabInstanceVariable](./dataGitlabInstanceVariable.typescript.md)
- [dataGitlabInstanceVariables](./dataGitlabInstanceVariables.typescript.md)
- [dataGitlabMetadata](./dataGitlabMetadata.typescript.md)
- [dataGitlabProject](./dataGitlabProject.typescript.md)
- [dataGitlabProjectBranches](./dataGitlabProjectBranches.typescript.md)
- [dataGitlabProjectHook](./dataGitlabProjectHook.typescript.md)
- [dataGitlabProjectHooks](./dataGitlabProjectHooks.typescript.md)
- [dataGitlabProjectIssue](./dataGitlabProjectIssue.typescript.md)
- [dataGitlabProjectIssues](./dataGitlabProjectIssues.typescript.md)
- [dataGitlabProjectMembership](./dataGitlabProjectMembership.typescript.md)
- [dataGitlabProjectMilestone](./dataGitlabProjectMilestone.typescript.md)
- [dataGitlabProjectMilestones](./dataGitlabProjectMilestones.typescript.md)
- [dataGitlabProjectProtectedBranch](./dataGitlabProjectProtectedBranch.typescript.md)
- [dataGitlabProjectProtectedBranches](./dataGitlabProjectProtectedBranches.typescript.md)
- [dataGitlabProjectTag](./dataGitlabProjectTag.typescript.md)
- [dataGitlabProjectTags](./dataGitlabProjectTags.typescript.md)
- [dataGitlabProjectVariable](./dataGitlabProjectVariable.typescript.md)
- [dataGitlabProjectVariables](./dataGitlabProjectVariables.typescript.md)
- [dataGitlabProjects](./dataGitlabProjects.typescript.md)
- [dataGitlabReleaseLink](./dataGitlabReleaseLink.typescript.md)
- [dataGitlabReleaseLinks](./dataGitlabReleaseLinks.typescript.md)
- [dataGitlabRepositoryFile](./dataGitlabRepositoryFile.typescript.md)
- [dataGitlabRepositoryTree](./dataGitlabRepositoryTree.typescript.md)
- [dataGitlabUser](./dataGitlabUser.typescript.md)
- [dataGitlabUserSshkeys](./dataGitlabUserSshkeys.typescript.md)
- [dataGitlabUsers](./dataGitlabUsers.typescript.md)
- [deployKey](./deployKey.typescript.md)
- [deployKeyEnable](./deployKeyEnable.typescript.md)
- [deployToken](./deployToken.typescript.md)
- [group](./group.typescript.md)
- [groupAccessToken](./groupAccessToken.typescript.md)
- [groupBadge](./groupBadge.typescript.md)
- [groupCluster](./groupCluster.typescript.md)
- [groupCustomAttribute](./groupCustomAttribute.typescript.md)
- [groupHook](./groupHook.typescript.md)
- [groupLabel](./groupLabel.typescript.md)
- [groupLdapLink](./groupLdapLink.typescript.md)
- [groupMembership](./groupMembership.typescript.md)
- [groupProjectFileTemplate](./groupProjectFileTemplate.typescript.md)
- [groupSamlLink](./groupSamlLink.typescript.md)
- [groupShareGroup](./groupShareGroup.typescript.md)
- [groupVariable](./groupVariable.typescript.md)
- [instanceCluster](./instanceCluster.typescript.md)
- [instanceVariable](./instanceVariable.typescript.md)
- [label](./label.typescript.md)
- [managedLicense](./managedLicense.typescript.md)
- [pagesDomain](./pagesDomain.typescript.md)
- [personalAccessToken](./personalAccessToken.typescript.md)
- [pipelineSchedule](./pipelineSchedule.typescript.md)
- [pipelineScheduleVariable](./pipelineScheduleVariable.typescript.md)
- [pipelineTrigger](./pipelineTrigger.typescript.md)
- [project](./project.typescript.md)
- [projectAccessToken](./projectAccessToken.typescript.md)
- [projectApprovalRule](./projectApprovalRule.typescript.md)
- [projectBadge](./projectBadge.typescript.md)
- [projectCluster](./projectCluster.typescript.md)
- [projectCustomAttribute](./projectCustomAttribute.typescript.md)
- [projectEnvironment](./projectEnvironment.typescript.md)
- [projectFreezePeriod](./projectFreezePeriod.typescript.md)
- [projectHook](./projectHook.typescript.md)
- [projectIssue](./projectIssue.typescript.md)
- [projectIssueBoard](./projectIssueBoard.typescript.md)
- [projectLevelMrApprovals](./projectLevelMrApprovals.typescript.md)
- [projectMembership](./projectMembership.typescript.md)
- [projectMilestone](./projectMilestone.typescript.md)
- [projectMirror](./projectMirror.typescript.md)
- [projectProtectedEnvironment](./projectProtectedEnvironment.typescript.md)
- [projectRunnerEnablement](./projectRunnerEnablement.typescript.md)
- [projectShareGroup](./projectShareGroup.typescript.md)
- [projectTag](./projectTag.typescript.md)
- [projectVariable](./projectVariable.typescript.md)
- [provider](./provider.typescript.md)
- [releaseLink](./releaseLink.typescript.md)
- [repositoryFile](./repositoryFile.typescript.md)
- [runner](./runner.typescript.md)
- [serviceEmailsOnPush](./serviceEmailsOnPush.typescript.md)
- [serviceExternalWiki](./serviceExternalWiki.typescript.md)
- [serviceGithub](./serviceGithub.typescript.md)
- [serviceJira](./serviceJira.typescript.md)
- [serviceMicrosoftTeams](./serviceMicrosoftTeams.typescript.md)
- [servicePipelinesEmail](./servicePipelinesEmail.typescript.md)
- [serviceSlack](./serviceSlack.typescript.md)
- [systemHook](./systemHook.typescript.md)
- [tagProtection](./tagProtection.typescript.md)
- [topic](./topic.typescript.md)
- [user](./user.typescript.md)
- [userCustomAttribute](./userCustomAttribute.typescript.md)
- [userGpgkey](./userGpgkey.typescript.md)
- [userSshkey](./userSshkey.typescript.md)

==> cdktf-cdktf-provider-gitlab-6.0.2.tar.gz: package/docs/API.typescript.md <==
# Submodules <a name="Submodules" id="submodules"></a>

The following submodules are available:
- [application](./application.typescript.md)
- [applicationSettings](./applicationSettings.typescript.md)
- [branch](./branch.typescript.md)
- [branchProtection](./branchProtection.typescript.md)
- [clusterAgent](./clusterAgent.typescript.md)
- [clusterAgentToken](./clusterAgentToken.typescript.md)
- [dataGitlabApplication](./dataGitlabApplication.typescript.md)
- [dataGitlabBranch](./dataGitlabBranch.typescript.md)
- [dataGitlabClusterAgent](./dataGitlabClusterAgent.typescript.md)
- [dataGitlabClusterAgents](./dataGitlabClusterAgents.typescript.md)
- [dataGitlabCurrentUser](./dataGitlabCurrentUser.typescript.md)
- [dataGitlabGroup](./dataGitlabGroup.typescript.md)
- [dataGitlabGroupHook](./dataGitlabGroupHook.typescript.md)
- [dataGitlabGroupHooks](./dataGitlabGroupHooks.typescript.md)
- [dataGitlabGroupMembership](./dataGitlabGroupMembership.typescript.md)
- [dataGitlabGroupSubgroups](./dataGitlabGroupSubgroups.typescript.md)
- [dataGitlabGroupVariable](./dataGitlabGroupVariable.typescript.md)
- [dataGitlabGroupVariables](./dataGitlabGroupVariables.typescript.md)
- [dataGitlabGroups](./dataGitlabGroups.typescript.md)
- [dataGitlabInstanceDeployKeys](./dataGitlabInstanceDeployKeys.typescript.md)
- [dataGitlabInstanceVariable](./dataGitlabInstanceVariable.typescript.md)
- [dataGitlabInstanceVariables](./dataGitlabInstanceVariables.typescript.md)
- [dataGitlabMetadata](./dataGitlabMetadata.typescript.md)
- [dataGitlabProject](./dataGitlabProject.typescript.md)
- [dataGitlabProjectBranches](./dataGitlabProjectBranches.typescript.md)
- [dataGitlabProjectHook](./dataGitlabProjectHook.typescript.md)
- [dataGitlabProjectHooks](./dataGitlabProjectHooks.typescript.md)
- [dataGitlabProjectIssue](./dataGitlabProjectIssue.typescript.md)
- [dataGitlabProjectIssues](./dataGitlabProjectIssues.typescript.md)
- [dataGitlabProjectMembership](./dataGitlabProjectMembership.typescript.md)
- [dataGitlabProjectMilestone](./dataGitlabProjectMilestone.typescript.md)
- [dataGitlabProjectMilestones](./dataGitlabProjectMilestones.typescript.md)
- [dataGitlabProjectProtectedBranch](./dataGitlabProjectProtectedBranch.typescript.md)
- [dataGitlabProjectProtectedBranches](./dataGitlabProjectProtectedBranches.typescript.md)
- [dataGitlabProjectTag](./dataGitlabProjectTag.typescript.md)
- [dataGitlabProjectTags](./dataGitlabProjectTags.typescript.md)
- [dataGitlabProjectVariable](./dataGitlabProjectVariable.typescript.md)
- [dataGitlabProjectVariables](./dataGitlabProjectVariables.typescript.md)
- [dataGitlabProjects](./dataGitlabProjects.typescript.md)
- [dataGitlabReleaseLink](./dataGitlabReleaseLink.typescript.md)
- [dataGitlabReleaseLinks](./dataGitlabReleaseLinks.typescript.md)
- [dataGitlabRepositoryFile](./dataGitlabRepositoryFile.typescript.md)
- [dataGitlabRepositoryTree](./dataGitlabRepositoryTree.typescript.md)
- [dataGitlabUser](./dataGitlabUser.typescript.md)
- [dataGitlabUserSshkeys](./dataGitlabUserSshkeys.typescript.md)
- [dataGitlabUsers](./dataGitlabUsers.typescript.md)
- [deployKey](./deployKey.typescript.md)
- [deployKeyEnable](./deployKeyEnable.typescript.md)
- [deployToken](./deployToken.typescript.md)
- [group](./group.typescript.md)
- [groupAccessToken](./groupAccessToken.typescript.md)
- [groupBadge](./groupBadge.typescript.md)
- [groupCluster](./groupCluster.typescript.md)
- [groupCustomAttribute](./groupCustomAttribute.typescript.md)
- [groupHook](./groupHook.typescript.md)
- [groupLabel](./groupLabel.typescript.md)
- [groupLdapLink](./groupLdapLink.typescript.md)
- [groupMembership](./groupMembership.typescript.md)
- [groupProjectFileTemplate](./groupProjectFileTemplate.typescript.md)
- [groupSamlLink](./groupSamlLink.typescript.md)
- [groupShareGroup](./groupShareGroup.typescript.md)
- [groupVariable](./groupVariable.typescript.md)
- [instanceCluster](./instanceCluster.typescript.md)
- [instanceVariable](./instanceVariable.typescript.md)
- [label](./label.typescript.md)
- [managedLicense](./managedLicense.typescript.md)
- [pagesDomain](./pagesDomain.typescript.md)
- [personalAccessToken](./personalAccessToken.typescript.md)
- [pipelineSchedule](./pipelineSchedule.typescript.md)
- [pipelineScheduleVariable](./pipelineScheduleVariable.typescript.md)
- [pipelineTrigger](./pipelineTrigger.typescript.md)
- [project](./project.typescript.md)
- [projectAccessToken](./projectAccessToken.typescript.md)
- [projectApprovalRule](./projectApprovalRule.typescript.md)
- [projectBadge](./projectBadge.typescript.md)
- [projectCluster](./projectCluster.typescript.md)
- [projectCustomAttribute](./projectCustomAttribute.typescript.md)
- [projectEnvironment](./projectEnvironment.typescript.md)
- [projectFreezePeriod](./projectFreezePeriod.typescript.md)
- [projectHook](./projectHook.typescript.md)
- [projectIssue](./projectIssue.typescript.md)
- [projectIssueBoard](./projectIssueBoard.typescript.md)
- [projectLevelMrApprovals](./projectLevelMrApprovals.typescript.md)
- [projectMembership](./projectMembership.typescript.md)
- [projectMilestone](./projectMilestone.typescript.md)
- [projectMirror](./projectMirror.typescript.md)
- [projectProtectedEnvironment](./projectProtectedEnvironment.typescript.md)
- [projectRunnerEnablement](./projectRunnerEnablement.typescript.md)
- [projectShareGroup](./projectShareGroup.typescript.md)
- [projectTag](./projectTag.typescript.md)
- [projectVariable](./projectVariable.typescript.md)
- [provider](./provider.typescript.md)
- [releaseLink](./releaseLink.typescript.md)
- [repositoryFile](./repositoryFile.typescript.md)
- [runner](./runner.typescript.md)
- [serviceCustomIssueTracker](./serviceCustomIssueTracker.typescript.md)
- [serviceEmailsOnPush](./serviceEmailsOnPush.typescript.md)
- [serviceExternalWiki](./serviceExternalWiki.typescript.md)
- [serviceGithub](./serviceGithub.typescript.md)
- [serviceJira](./serviceJira.typescript.md)
- [serviceMicrosoftTeams](./serviceMicrosoftTeams.typescript.md)
- [servicePipelinesEmail](./servicePipelinesEmail.typescript.md)
- [serviceSlack](./serviceSlack.typescript.md)
- [systemHook](./systemHook.typescript.md)
- [tagProtection](./tagProtection.typescript.md)
- [topic](./topic.typescript.md)
- [user](./user.typescript.md)
- [userCustomAttribute](./userCustomAttribute.typescript.md)
- [userGpgkey](./userGpgkey.typescript.md)
- [userSshkey](./userSshkey.typescript.md)
